=======
History
=======

0.1.1 (2016-08-16)
------------------
* Completed docstrings and amendments to documentation
* Added list_to_html under gwrappy.gmail.utils
* Added tabulate as a dependency

0.1.0 (2016-08-15)
------------------

* New and improved version of https://github.com/danielpoonwj/gcloud_custom_utilities
* First release on PyPI.
